.. glowgreen documentation master file, created by
   sphinx-quickstart on Thu Oct  6 19:36:11 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to glowgreen's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
